@@ -57,6 +57,8 @@ class Serialization(SerializationInterface):
         """
         server_prefix = self._server_prefix()
         lines = []
+        title = 'Tiddlers'
+        representation_link = ''
         for tiddler in bag.gen_tiddlers():
             base, base_link, representation_link, title = \
                     self._tiddler_list_info(tiddler)
